AdminDataSourceImpl class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearPasswordReset({required String email, required String table, String? authorization})
→ Future<Map<String, Object?>>
-
override
-
invite({required AdminInviteBody body, String? authorization})
→ Future<Map<String, Object?>>
-
override
-
members({String? authorization})
→ Future<Map<String, Object?>>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
passwordResetRequirement({required String email, required String table, String? authorization})
→ Future<Map<String, Object?>>
-
override
-
removeMember({required String email, String? authorization})
→ Future<Map<String, Object?>>
-
override
-
requirePasswordReset({required String email, required String table, String? reason, String? authorization})
→ Future<Map<String, Object?>>
-
override
-
revokeInvite({required String email, String? authorization})
→ Future<void>
-
override
-
toString()
→ String
-
A string representation of this object.
inherited