DashboardDataSourceImpl class

Implemented types

Constructors

DashboardDataSourceImpl({required RevaliClient client, required Storage storage})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

metrics({int? since, bool? excludeAdmin, String? authorization}) Future<DashboardMetrics>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
storage({String? authorization}) Future<StorageMetrics>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited