DbDataSourceImpl class

Implemented types

Constructors

DbDataSourceImpl({required RevaliClient client, required Storage storage})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count({required CountBody body, String? authorization}) Future<int>
override
create({required CreateBody body, String? authorization}) Future<Map<String, Object?>>
override
createMany({required CreateManyBody body, String? authorization}) Future<List<Map<String, Object?>>>
override
custom({required String operation, required CustomOneBody body, String? authorization}) Future<Map<String, Object?>>
override
customMany({required String operation, required CustomBody body, String? authorization}) Future<List<Map<String, Object?>>>
override
delete({required DeleteOneBody body, String? authorization}) Future<void>
override
deleteMany({required DeleteBody body, String? authorization}) Future<void>
override
get({required GetBody body, String? authorization}) Future<Map<String, Object?>>
override
list({required ListBody body, String? authorization}) Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamCount({required StreamCountBody body, String? authorization}) Stream<int>
override
streamList({required StreamListBody body, String? authorization}) Stream<List<Map<String, Object?>>>
override
streamOne({required StreamBody body, String? authorization}) Stream<Map<String, Object?>>
override
toString() String
A string representation of this object.
inherited
update({required UpdateOneBody body, String? authorization}) Future<Map<String, Object?>>
override
updateMany({required UpdateBody body, String? authorization}) Future<List<Map<String, Object?>>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited