RootDataSourceImpl class
- Implemented types
Constructors
- RootDataSourceImpl({required RevaliClient client, required Storage storage})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
favicon(
) → Stream< List< int> > -
override
-
health(
) → Future< void> -
override
-
logo(
) → Stream< List< int> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
swaggerJson(
{String? authorization}) → Future< String> -
override
-
swaggerYaml(
{String? authorization}) → Future< String> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited