Server class

Constructors

Server({HttpClient? client, Storage? storage, Uri? baseUrl})

Properties

admin → AdminDataSource
latefinal
apiToken → ApiTokenDataSource
latefinal
auth → AuthDataSource
latefinal
client ↔ RevaliClient
latefinal
cron → CronDataSource
latefinal
dashboard → DashboardDataSource
latefinal
db → DbDataSource
latefinal
email → EmailDataSource
latefinal
hashCode → int
The hash code for this object.
no setterinherited
maintenance → MaintenanceDataSource
latefinal
photos → PhotosDataSource
latefinal
push → PushDataSource
latefinal
root → RootDataSource
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage ↔ Storage
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited