AdminDataSource class abstract interface

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearPasswordReset({required String email, required String table, String? authorization}) → Future<Map<String, Object?>>
invite({required AdminInviteBody body, String? authorization}) → Future<Map<String, Object?>>
members({String? authorization}) → Future<Map<String, Object?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
passwordResetRequirement({required String email, required String table, String? authorization}) → Future<Map<String, Object?>>
removeMember({required String email, String? authorization}) → Future<Map<String, Object?>>
requirePasswordReset({required String email, required String table, String? reason, String? authorization}) → Future<Map<String, Object?>>
revokeInvite({required String email, String? authorization}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited