- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required ApiTokenCreateBody body, String? authorization}) → Future< Map< String, Object?> > -
delete(
{required String id, String? authorization}) → Future< void> -
list(
{String? authorization}) → Future< Map< String, Object?> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revoke(
{required String id, String? authorization}) → Future< Map< String, Object?> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited