AuthDataSource class abstract interface

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptAdminInvite({required AdminInviteAcceptBody body}) → Future<Map<String, Object?>>
adminAuthenticate({required AdminAuthBody body}) → Future<Map<String, Object?>?>
adminInviteStatus({required String token}) → Future<Map<String, Object?>>
authenticate({required AuthBody body, String? authorization}) → Future<Map<String, Object?>?>
confirm({required VerifyAuthBody body}) → Future<Map<String, Object?>?>
confirmUpgrade({required ConfirmUpgradeAuthBody body, required String authorization}) → Future<Map<String, Object?>>
logout({required String authorization}) → Future<void>
logoutAll({required String authorization}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
oauth({required OAuthBody body}) → Future<Map<String, Object?>>
oauthCallback({required String provider, String? code, String? state, String? error}) → Future<void>
oauthCallbackFormPost({required String provider, required OAuthCallbackBody body}) → Future<void>
oauthProviders({String? table}) → Future<List<Map<String, Object?>>>
refreshToken({required String authorization}) → Future<Map<String, Object?>?>
requestUpgrade({required UpgradeAuthBody body, required String authorization}) → Future<void>
resumeAnonymous({required ResumeAnonymousAuthBody body}) → Future<Map<String, Object?>>
sendResetPassword({required ResetPasswordAuthBody body, String? authorization}) → Future<void>
sendVerifyEmail({VerifyEmailAuthBody? body, required String authorization}) → Future<void>
signIn({required SignInAuthBody body}) → Future<Map<String, Object?>>
signInAnonymously({required AnonymousAuthBody body, String? authorization}) → Future<Map<String, Object?>>
signUp({required SignUpAuthBody body, String? authorization}) → Future<Map<String, Object?>>
startAdminInviteOAuth({required String provider, required String token, String? redirectTo}) → Future<void>
startAdminOAuth({required String provider, String? redirectTo, String? authorization}) → Future<void>
startOAuth({required String provider, required String table, String? redirectTo, String? authorization}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited