DbDataSource class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count({required CountBody body, String? authorization}) Future<int>
create({required CreateBody body, String? authorization}) Future<Map<String, Object?>>
createMany({required CreateManyBody body, String? authorization}) Future<List<Map<String, Object?>>>
custom({required String operation, required CustomOneBody body, String? authorization}) Future<Map<String, Object?>>
customMany({required String operation, required CustomBody body, String? authorization}) Future<List<Map<String, Object?>>>
delete({required DeleteOneBody body, String? authorization}) Future<void>
deleteMany({required DeleteBody body, String? authorization}) Future<void>
get({required GetBody body, String? authorization}) Future<Map<String, Object?>>
list({required ListBody body, String? authorization}) Future<Map<String, Object?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamCount({required StreamCountBody body, String? authorization}) Stream<int>
streamList({required StreamListBody body, String? authorization}) Stream<List<Map<String, Object?>>>
streamOne({required StreamBody body, String? authorization}) Stream<Map<String, Object?>>
toString() String
A string representation of this object.
inherited
update({required UpdateOneBody body, String? authorization}) Future<Map<String, Object?>>
updateMany({required UpdateBody body, String? authorization}) Future<List<Map<String, Object?>>>

Operators

operator ==(Object other) bool
The equality operator.
inherited