MaintenanceDataSource class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanupPhotos({String? authorization}) Future<PhotoCleanupResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeLogs({required PurgeLogsBody body, String? authorization}) Future<MaintenanceRowsResult>
purgeTable({required PurgeTableBody body, String? authorization}) Future<MaintenanceRowsResult>
reclaimLogSpace({String? authorization}) Future<LogSpaceReclamationResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited