AuthBody class sealed

Constructors

factory
AuthBody.adminSendOtp({required String email, Map<String, dynamic>? metadata})
factory
AuthBody.adminSignIn({required String email, required String password})
factory
AuthBody.fromJson(Map<String, dynamic> json)
factory
factory
AuthBody.sendOtp({required String table, required String email, Map<String, dynamic>? metadata})
factory
AuthBody.signIn({required String table, required String email, required String password})
factory
AuthBody.signUp({required String table, required String email, required String password, required Map<String, dynamic> object})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited