DeleteBody class

Constructors

DeleteBody({required String table, required Where where, int? limit})
const
DeleteBody.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
where Where
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited