OrderByTerm class

Constructors

OrderByTerm({required String column, SortDirection direction = SortDirection.asc})
const
OrderByTerm.fromJson(Map json)
factory

Properties

column → String
final
direction → SortDirection
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited