StreamBody class

Constructors

StreamBody({required String table, required Where where, List<String> expand = const []})
const
StreamBody.fromJson(Map<String, dynamic> json)
factory

Properties

expand → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → String
final
where → Where
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited