Where class sealed

Constructors

Where.fromJson(Map json)
factory
Where.isNotNull(String column)
column IS NOT NULL. See Where.isNull for why this factory exists.
const
factory
Where.isNull(String column)
column IS NULL.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited