AdminDataSourceImpl class

Implemented types

Constructors

AdminDataSourceImpl({required RevaliClient client, required Storage storage})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invite({required AdminInviteBody body, String? authorization}) Future<Map<String, Object?>>
override
members({String? authorization}) Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMember({required String email, String? authorization}) Future<Map<String, Object?>>
override
revokeInvite({required String email, String? authorization}) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited