PhotosDataSourceImpl class
- Implemented types
Constructors
- PhotosDataSourceImpl({required RevaliClient client, required Storage storage})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required Stream< List< image, required PhotoCreateMeta meta, String? authorization, String? contentType}) → Future<int> >Map< String, Object?> > -
override
-
delete(
{required String id, String? authorization}) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
{required String id, required Stream< List< image, String? authorization}) → Future<int> >void> -
override
-
view(
{required String id, String? authorization}) → Stream< List< int> > -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited