- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invite(
{required AdminInviteBody body, String? authorization}) → Future< Map< String, Object?> > -
members(
{String? authorization}) → Future< Map< String, Object?> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeMember(
{required String email, String? authorization}) → Future< Map< String, Object?> > -
revokeInvite(
{required String email, String? authorization}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited